/*
This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

In jurisdictions that recognize copyright laws, the author or authors
of this software dedicate any and all copyright interest in the
software to the public domain. We make this dedication for the benefit
of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of
relinquishment in perpetuity of all present and future rights to this
software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to <http://unlicense.org/>
*/
//============================================================================
// CFAG12864C Demonstration code
// ST7920 LCD Controller
// Atmel ATMega32 processor @ 16MHz
// WinAVR / AVR GCC + Atmel AVR Studio
// Written by Brent A. Crosby
// Modified by Max Roberg
// Crystalfontz America, Inc.
//============================================================================
#include <avr/io.h>
#include "utils.h"
#include "timer.h"
#include "delay_x.h"
#include "logo_screen.h"
#include "low_lcd.h"


//============================================================================
// Port Direction Initialization.
//
// This routine will set the default processor port directions.
//----------------------------------------------------------------------------
void Initialize_GPIO(void)
{
/* Port A - Bit 7: LCD_DB7,    			output, low
 *              6: LCD_DB6,             output, low
 *              5: LCD_DB5,        		output, low
 *              4: LCD_DB4,          	output, low
 *              3: LCD_DB3,             output, low
 *              2: LCD_DB2,             output, low
 *              1: LCD_DB1,             output, low
 *              0: LCD_DB0,             output, low
 */
     DDRA =  0b11111111;
     PORTA = 0b00000000;



/* Port B - Bit 7: LCD_CONTRAST_PWM,    output, low
 *              6: NC,                  output, low
 *              5: NC,					        output, low
 *              4: NC,					        output, low
 *              3: MISO,                output, low
 *              2: MOSI,                output, low
 *              1: SCK,                 output, low
 *              0: nSS,                 output, low
 */
     DDRB =  0b11111111;
     PORTB = 0b00000000;


/* Port C - Bit 7: LCD_DI,              output, high
 *              6: LCD_RW,              output, high
 *              5: LCD_E,               output, low
 *              4: LCD_CS1,             output, high
 *              3: LCD_CS2,             output, high
 *              2: LCD_RST,             output, low
 *              1: LCD_CS3,             output, high
 *              0: NC                   input, pull-up
 */
     DDRC =  0b11111110;
     PORTC = 0b11011011;

/* Port D - Bit 7: KEY0,                input, pull-up
 *              6: KEY1,                input, pull-up
 *              5: KEY2,                input, pull-up
 *              4: KEY3,                input, pull-up
 *              3: NC,                  input, pull-up
 *              2: LED2,                input, pull-up
 *              1: LED1,                input, pull-up
 *              0: NC,                  input, pull-up
 */
     DDRD =  0b00000110;
     PORTD = 0b11111001;

/* Port E - Bit 7: NC,                  input, pull-up
 *              6: NC,                  input, pull-up
 *              5: NC,                  input, pull-up
 *              4: NC,                  input, pull-up
 *              3: LCD_BL_GRN,          output, high
 *              2: NC,                  input, pull-up
 *              1: NC,                  input, pull-up
 *              0: NC,                  input, pull-up
 */
     DDRE =  0b00001000;
     PORTE = 0b11111111;

/* Port G - Bit 7: NC,                  input, pull-up
 *              6: NC,                  input, pull-up
 *              5: NC,                  input, pull-up
 *              4: LCD_EL,              output, high
 *              3: NC,                  input, pull-up
 *              2: NC,                  input, pull-up
 *              1: NC,                  input, pull-up
 *              0: NC,                  input, pull-up
 */
     DDRG =  0b00010000;
     PORTG = 0b11111111;
}

void Initialize_contrast_backlight_and_LCD()
{

    // copy the bitmap from flash to memory
//	memcpy_P(display, boot_logo, sizeof(display));

	// Initializes the LCD, also takes LCD out of reset
	InitializeLCD();

	// Copies from the array in flash to RAM
    memcpy_P(display, cfag12864s, sizeof(display));
}
